@@ -26,7 +26,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsgrep.c 2615 2021-02-18 20:55:16Z pbuchbinder $";
+static const char revision[] = "$Id: qsgrep.c 2622 2021-08-08 20:54:09Z pbuchbinder $";
 
 /* system */
 #include <stdio.h>
@@ -97,7 +97,7 @@ static void usage(char *cmd, int man) {
   if(man) printf(".TP\n");
   qs_man_print(man, "  -e <pattern>\n");
   if(man) printf("\n");
-  qs_man_print(man, "     Specifes the search pattern.\n");
+  qs_man_print(man, "     Specifies the search pattern.\n");
   if(man) printf("\n.TP\n");
   qs_man_print(man, "  -o <string>\n");
   if(man) printf("\n");
