@@ -27,7 +27,7 @@
  *
  */
 
-static const char revision[] = "$Id: qshead.c 2615 2021-02-18 20:55:16Z pbuchbinder $";
+static const char revision[] = "$Id: qshead.c 2622 2021-08-08 20:54:09Z pbuchbinder $";
 
 #include <stdio.h>
 #include <unistd.h>
@@ -62,7 +62,7 @@ static void usage(char *cmd, int man) {
   } else {
     printf("Summary\n");
   }
-  qs_man_print(man, " %s reads lines from stdin and prints them to stdout unitl a line contains\n", cmd);
+  qs_man_print(man, " %s reads lines from stdin and prints them to stdout until a line contains\n", cmd);
   qs_man_print(man, " the specified pattern (literal string).\n");
   printf("\n");
   if(man) {
