@@ -23,7 +23,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsre.c 2615 2021-02-18 20:55:16Z pbuchbinder $";
+static const char revision[] = "$Id: qsre.c 2622 2021-08-08 20:54:09Z pbuchbinder $";
 
 /* system */
 #include <stdio.h>
@@ -87,7 +87,7 @@ static void usage(const char *cmd, int man) {
   if(man) printf(".TP\n");
   qs_man_print(man, "  <string>|<path>\n");
   if(man) printf("\n");
-  qs_man_print(man, "     The first argument either defines a sinlge test string of a path to\n");
+  qs_man_print(man, "     The first argument either defines a single test string of a path to\n");
   qs_man_print(man, "     a file containing either multiple test strings or a test pattern with\n");
   qs_man_print(man, "     newline characters (text).\n");
   if(man) printf("\n.TP\n");
